{% extends 'base.html' %}
{% load bootstrap3 %}

{% block body %}
        <div class="row">
        <div class="page-header">
            <h1>Add Foo item</h1>
        </div>
    </div>

    <div class="row">
        <div class="col-sm-6">

            <form action="" method="post" class="form">
                {% csrf_token %}
                {% bootstrap_form form %}
                {% buttons %}
                    <button type="submit" class="btn btn-primary">
                        {% bootstrap_icon "plus" %} Add
                    </button>
                {% endbuttons %}
            </form>
        </div>
    </div>

{% endblock %}
